@@ -14,7 +14,7 @@ def amplitude(x, y, lx, ly):
     return np.where(h > 0, h, 0)
 
 @numba.njit()
-def deriv(y, t):
+def deriv(y, _):
     """
     return derivatives of [lambda_x, dlambda_x/dt, lambda_y, dlambda_y/dt
     four first-order ODEs based on  eq. 7  (Jarecka, Jaruga, Smolarkiewicz)
@@ -25,7 +25,8 @@ def deriv(y, t):
 def d2_el_lamb_lamb_t_evol(times, lamb_x0, lamb_y0):
     """
     solving coupled nonlinear second-order ODEs - eq. 7  (Jarecka, Jaruga, Smolarkiewicz)
-    returning array with first dim denoting time, second dim: [\lambda_x, \dot{\lambda_x}, \lambda_y, \dot{\lambda_y}
+    returning array with first dim denoting time, second dim:
+    [lambda_x, dot{lambda_x}, lambda_y, dot{lambda_y}
     """
     assert times[0] == 0
     yinit = np.array([lamb_x0, 0., lamb_y0, 0.])  # initial values (dot_lamb = 0.)
